#
# spec file for package warpinator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           warpinator
Version:        1.6.4
Release:        1.1
Summary:        Share files across the LAN
License:        GPL-3.0-or-later
URL:            https://github.com/linuxmint/warpinator
Source:         https://github.com/linuxmint/warpinator/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  glib2-tools
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  polkit-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-grpcio
BuildRequires:  python3-protobuf
BuildRequires:  python3-setuptools
BuildRequires:  python3-zeroconf
BuildRequires:  update-desktop-files
Requires:       python3-PyNaCl
Requires:       python3-cryptography
Requires:       python3-gobject-Gdk
Requires:       python3-grpcio
Requires:       python3-netifaces
Requires:       python3-protobuf
Requires:       python3-setproctitle
Requires:       python3-xapp
Requires:       python3-zeroconf

BuildArch:      noarch
%lang_package

%description
Warpinator is a simple app that allows users to share files across the LAN.

%package -n nemo-extension-%{name}
Summary:        Warpinator extension for nemo
Requires:       nemo
Requires:       warpinator = %{version}
Supplements:    (nemo and warpinator)
BuildArch:      noarch

%description -n nemo-extension-%{name}
Warpinator is a simple app that allows users to share files across the LAN.

This package provides an extension to use warpinator from nemo file browser.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%meson \
%if 0%{?suse_version} >= 1550
       --sysconfdir=%{_distconfdir} \
%endif
       -Dbundle-zeroconf=false \
       -Dinclude-firewall-mod=false
%meson_build

%install
%meson_install

# Files missing hashbangs
for f in config warp_pb2 warp_pb2_grpc
do
  sed -i "1i#!%{_bindir}/python3" %{buildroot}%{_libexecdir}/warpinator/${f}.py
done

chmod +x %{buildroot}%{_libexecdir}/warpinator/*.py

%suse_update_desktop_file -r org.x.Warpinator Network FileTransfer
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING
%doc README.md
%if 0%{?suse_version} >= 1550
%{_distconfdir}/xdg/autostart/warpinator-autostart.desktop
%else
%{_sysconfdir}/xdg/autostart/warpinator-autostart.desktop
%endif
%{_bindir}/warpinator
%{_bindir}/warpinator-send
%{_libexecdir}/warpinator/
%{_datadir}/applications/org.x.Warpinator.desktop
%{_datadir}/glib-2.0/schemas/org.x.Warpinator.gschema.xml
%dir %{_datadir}/icons/hicolor/*@2
%dir %{_datadir}/icons/hicolor/*@2/apps
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.x.Warpinator.appdata.xml
%{_datadir}/warpinator/

%files -n nemo-extension-%{name}
%dir %{_datadir}/nemo
%dir %{_datadir}/nemo/actions
%{_datadir}/nemo/actions/warpinator*

%files lang -f %{name}.lang

%changelog
* Sun Jul 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.4:
  * Allow to override build date with SOURCE_DATE_EPOCH
  * l10n: Update translations
* Sat Jun 10 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.6.3:
  * Update translations
- Changes from version 1.6.2:
  * Possible remaining_count fixes
  * Fix a typo and add bash syntax highlighting to README
* Fri Apr 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add BuildRequires: gobject-introspection to autodetect typelib
  Requires and drop manual Requires for typelib-1_0-Gtk-3_0,
  typelib-1_0-NM-1_0, and typelib-1_0-XApp-1_0.
* Thu Apr 27 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.1 [boo#1203463, boo#1207480]:
  * warpinator-launch.py: Fix bubblewrap launch string.
  * warpinator-send: Give a better error if warpinator isn't
    running.
  * Add /dev back to bubblewrap args.
- Changes from version 1.6.0:
  * build: Fix deprecation warning.
  * notifications: Fix indentation.
  * Improve some logging.
  * remote: Improve readability of rpc calls.
  * Migrate group code and connect ids to gsettings.
  * Include the python landlock module.
  * Implement incoming folder isolation.
  * Improve incoming file path validation.
  * Forbid some locations from being chosen as the save folder.
  * Check if recents can be written to before attempting it.
  * Move some util functions into a new file.
  * Add warpinator-send utility.
  * bubblewrap: Fixes for debian/lmde.
  * transfers.py: Use generic getter for file content type.
  * build: Fix dh_python3 byte-compilation.
  * Simplify startup scripts.
  * Remove some remnants of a previous grpc version.
  * free space monitor: Improve readability, comments.
  * free space: Don't run the monitor when only sending files.
  * Clean up --help information, add a new section to the README
    to explain landlock, bubblewrap.
  * Add an infobar for a sandbox warning.
  * Cleanup bubblewrap arguments, sandbox_mode setting, exit if
    the user specifies a mode that isn't available, explain file
    manager launch complexities.
  * Simpliy NewThreadExecutor a bit.
- Add hashbangs where they are required but missing.
- Split out a new nemo-extension-warpinator package that provides
  context menu items from the nemo file browser.
* Wed Jan 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.3:
  * Updated translations.
- Changes from version 1.4.2:
  * Updated translations.
- Changes from version 1.4.1:
  * auth.py: remove leftover self, and get_group_code() always
    needs to return a code.
- Changes from version 1.4.0:
  * Rework group code presentation and enforcement in preferences.
  * Updated translations.
- Drop warpinator-safe-destination.patch: incorporated upstream.
* Sat Oct  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.14:
  * grpc: Use 1.44 instead of 1.46 for now - there is a polling
    issue in 1.46+ that causes excessive CPU use.
- Add warpinator-safe-destination.patch: Fix transfer destinations
  so they cannot overwrite files/dirs outside of upload directory
  [bsc#1203463, CVE-2022-42725].
- Pass sysconfdir=%%{_distconfdir} to meson for openSUSE >= 1550;
  this moves the autostart file to the more appropriate location:
  /usr/etc instead of /etc; there are no conf files that are
  installed to /etc anyway.
- Drop polkit privileges file: We do not have ufw in the distro,
  so this is pretty much useless for us anyway.
- Drop BuildRequires: python3-grpcio-tools, not required.
* Thu Sep 15 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add Requires: python3-protobuf, needed at runtime as well.
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.13:
  * Updated translations.
- Changes from version 1.2.12:
  * UI: Add links to altinators.
  * Updated translations.
* Tue Jun 28 2022 malcolmlewis@opensuse.org
- Updated to version 1.2.11:
  * Translation updates.
- Changes from version 1.2.10:
  * Remove a comment that no longer applies.
  * auth.py: Limit the length of the zeroconf service name.
  * transfers: Don't try to set mtime or mode on symlinks, and fix
    folder permission setting.
  * Update readme.
  * make other platforms a bulleted list.
  * Add some troubleshooting tips to the readme.
  * Fix network device name fetching.
  * Update README.md.
  * Add keywords to .desktop file.
* Sat Jan 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.9:
  * Transfers: Make transfers cancellable by the receiving
    computer once more.
  * server.py: Fix regression from 2cd3b660c that was preventing
    existing ops from being restarted by the sender.
  * transfers: Improve on 069cf5f57e6 by creating a generator
    object to wrap the origin response instead of returning two
    objects.
- Drop warpinator-libexec-dir.patch: openSUSE uses
  %%_prefix/libexec for %%_libexecdir now.
* Sun Aug  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add warpinator-libexec-dir.patch to replace hard-coded
  '/usr/libexecdir' by '/usr/lib'.
* Mon Jun 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
